### Name: glhHmat
### Title: Total and Effect Deviation Matrices for General Linear
###   Hypothesis
### Aliases: glhHmat glhHmat.default glhHmat.formula glhHmat.data.frame
### Keywords: manip

### ** Examples

##----------------------------------------------------------------------------

##  The following examples create T and H matrices for different
## analysis of the MASS data set "crabs". This data 
##  records physical measurements on 200 specimens of Leptograpsus
## variegatus crabs observed on the shores of 
##  Western Australia. The crabs are classified by two factors, sex
## and sp (crab species as defined by its 
##  colour: blue or orange), with two levels each. The measurement
## variables include the carapace length (CL), c
##  the carapace width (CW), the size of the frontal lobe (FL) and the
## size of the rear width (RW). In the  
##  analysis provided, we assume that there is an interest in
## comparing the subsets of these variables measured in their original 
##  and logarithmic scales.        

library(MASS)
data(crabs)
lFL <- log(crabs$FL)
lRW <- log(crabs$RW)
lCL <- log(crabs$CL)
lCW <- log(crabs$CW)

# 1)  Create the T and H matrices associated with a linear
# discriminant analysis on the groups defined by the sp factor.  
# This call is equivalent to ldaHmat(sp ~ FL + RW + CL + CW  + lFL +
# lRW + lCL + lCW,crabs) 

glhHmat(cbind(FL,RW,CL,CW,lFL,lRW,lCL,lCW) ~ sp,c(0,1),crabs)

# 2) Create the T and H matrices associated with a linear discriminant
# analysis on the groups defined by the sex factor. 
# This call is equivalent to ldaHmat(sex ~ FL + RW + CL + CW  + lFL +
# lRW + lCL + lCW,crabs) 

glhHmat(cbind(FL,RW,CL,CW,lFL,lRW,lCL,lCW) ~ sex,c(0,1),crabs)

# 3)  Create the T and H matrices associated with a linear
# discriminant analysis on the groups 
# defined by all the combinations of the sp and sex factors

C <- matrix(0.,3,4)
C[row(C)+1 == col(C)] = 1.
glhHmat(cbind(FL,RW,CL,CW,lFL,lRW,lCL,lCW) ~ sp*sex,C,crabs)

# 4)  Create the T and H matrices associated with an analysis
# of the interactions between the sp and sex factors

glhHmat(cbind(FL,RW,CL,CW,lFL,lRW,lCL,lCW) ~ sp*sex,c(0,0,0,1),crabs)

# 5)  Create the T and H matrices associated with an analysis
# of the effect of the sp factor after controlling for sex

C <- matrix(0.,2,4)
C[1,3] = C[2,4] = 1.
glhHmat(cbind(FL,RW,CL,CW,lFL,lRW,lCL,lCW) ~ sp*sex,C,crabs)




